# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 capacity: pulumi.Input[builtins.int],
                 file_system_name: pulumi.Input[builtins.str],
                 store_type: pulumi.Input[builtins.str],
                 zone_id: pulumi.Input[builtins.str],
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_restripe: Optional[pulumi.Input[builtins.bool]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 version_number: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[builtins.int] capacity: 文件系统容量，单位为 TiB。
        :param pulumi.Input[builtins.str] file_system_name: 文件系统名称。命名规范如下：只能以中文或英文开头。只能包含中文、字母、数字、半角句号（.）、下划线（_）或中划线（-）。长度需要在 1~128 个字符内。
        :param pulumi.Input[builtins.str] store_type: 文件系统规格，取值说明如下：Advance*100：100MB/s/TiB。Performance：性能版。Intelligent*Computing：智算版。
        :param pulumi.Input[builtins.str] zone_id: 可用区 ID。
        :param pulumi.Input[builtins.str] charge_type: 计费类型。取值说明如下：PayAsYouGo：按量计费。
        :param pulumi.Input[builtins.str] description: 文件系统描述信息。
        :param pulumi.Input[builtins.bool] enable_restripe: 扩容后是否开启数据均衡，取值说明如下：true：扩容后立即开启数据均衡。false：扩容后不开启数据均衡。注意：仅 100MB/s/TiB 规格的文件系统支持数据均衡功能。由于数据均衡过程会消耗存储节点的网络和磁盘带宽，导致文件系统的性能下降，建议您评估业务需求，谨慎开启。数据均衡的时间主要受存量数据量的影响，如果您的存量数据较多，均衡的时间可能会较长，根据扩容容量大小和文件系统状态，此过程可能需要花费数小时至 2 天的时间，建议您在业务低峰期开启并耐心等待。
        :param pulumi.Input[builtins.str] file_system_type: 文件系统类型，默认为 VePFS。
        :param pulumi.Input[builtins.str] project_name: 文件系统所属项目，默认为 default。
        :param pulumi.Input[builtins.str] protocol_type: 协议类型，默认为 VePFS。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。子网必须属于所选的可用区。
        :param pulumi.Input[builtins.str] version_number: 文件系统版本号。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        """
        pulumi.set(__self__, "capacity", capacity)
        pulumi.set(__self__, "file_system_name", file_system_name)
        pulumi.set(__self__, "store_type", store_type)
        pulumi.set(__self__, "zone_id", zone_id)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_restripe is not None:
            pulumi.set(__self__, "enable_restripe", enable_restripe)
        if file_system_type is not None:
            pulumi.set(__self__, "file_system_type", file_system_type)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if protocol_type is not None:
            pulumi.set(__self__, "protocol_type", protocol_type)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if version_number is not None:
            pulumi.set(__self__, "version_number", version_number)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def capacity(self) -> pulumi.Input[builtins.int]:
        """
        文件系统容量，单位为 TiB。
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> pulumi.Input[builtins.str]:
        """
        文件系统名称。命名规范如下：只能以中文或英文开头。只能包含中文、字母、数字、半角句号（.）、下划线（_）或中划线（-）。长度需要在 1~128 个字符内。
        """
        return pulumi.get(self, "file_system_name")

    @file_system_name.setter
    def file_system_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "file_system_name", value)

    @property
    @pulumi.getter(name="storeType")
    def store_type(self) -> pulumi.Input[builtins.str]:
        """
        文件系统规格，取值说明如下：Advance*100：100MB/s/TiB。Performance：性能版。Intelligent*Computing：智算版。
        """
        return pulumi.get(self, "store_type")

    @store_type.setter
    def store_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "store_type", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[builtins.str]:
        """
        可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        计费类型。取值说明如下：PayAsYouGo：按量计费。
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableRestripe")
    def enable_restripe(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        扩容后是否开启数据均衡，取值说明如下：true：扩容后立即开启数据均衡。false：扩容后不开启数据均衡。注意：仅 100MB/s/TiB 规格的文件系统支持数据均衡功能。由于数据均衡过程会消耗存储节点的网络和磁盘带宽，导致文件系统的性能下降，建议您评估业务需求，谨慎开启。数据均衡的时间主要受存量数据量的影响，如果您的存量数据较多，均衡的时间可能会较长，根据扩容容量大小和文件系统状态，此过程可能需要花费数小时至 2 天的时间，建议您在业务低峰期开启并耐心等待。
        """
        return pulumi.get(self, "enable_restripe")

    @enable_restripe.setter
    def enable_restripe(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_restripe", value)

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统类型，默认为 VePFS。
        """
        return pulumi.get(self, "file_system_type")

    @file_system_type.setter
    def file_system_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_type", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统所属项目，默认为 default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        协议类型，默认为 VePFS。
        """
        return pulumi.get(self, "protocol_type")

    @protocol_type.setter
    def protocol_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol_type", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网 ID。子网必须属于所选的可用区。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统版本号。
        """
        return pulumi.get(self, "version_number")

    @version_number.setter
    def version_number(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_number", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 capacity: Optional[pulumi.Input[builtins.int]] = None,
                 capacity_info: Optional[pulumi.Input['InstanceCapacityInfoArgs']] = None,
                 charge_status: Optional[pulumi.Input[builtins.str]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_restripe: Optional[pulumi.Input[builtins.bool]] = None,
                 expire_time: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_id: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_name: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 free_time: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 security_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 stop_service_time: Optional[pulumi.Input[builtins.str]] = None,
                 store_type: Optional[pulumi.Input[builtins.str]] = None,
                 store_type_cn: Optional[pulumi.Input[builtins.str]] = None,
                 store_type_en: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 version_number: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 write_bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[builtins.str] account_id: 账户ID。
        :param pulumi.Input[builtins.int] bandwidth: vePFS 文件系统吞吐上限。
        :param pulumi.Input[builtins.int] capacity: 文件系统容量，单位为 TiB。
        :param pulumi.Input['InstanceCapacityInfoArgs'] capacity_info: 容量信息。
        :param pulumi.Input[builtins.str] charge_status: 计费状态，默认为 Normal，表示正常计费。
        :param pulumi.Input[builtins.str] charge_type: 计费类型。取值说明如下：PayAsYouGo：按量计费。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 文件系统描述信息。
        :param pulumi.Input[builtins.bool] enable_restripe: 扩容后是否开启数据均衡，取值说明如下：true：扩容后立即开启数据均衡。false：扩容后不开启数据均衡。注意：仅 100MB/s/TiB 规格的文件系统支持数据均衡功能。由于数据均衡过程会消耗存储节点的网络和磁盘带宽，导致文件系统的性能下降，建议您评估业务需求，谨慎开启。数据均衡的时间主要受存量数据量的影响，如果您的存量数据较多，均衡的时间可能会较长，根据扩容容量大小和文件系统状态，此过程可能需要花费数小时至 2 天的时间，建议您在业务低峰期开启并耐心等待。
        :param pulumi.Input[builtins.str] expire_time: 过期时间。
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] file_system_name: 文件系统名称。命名规范如下：只能以中文或英文开头。只能包含中文、字母、数字、半角句号（.）、下划线（_）或中划线（-）。长度需要在 1~128 个字符内。
        :param pulumi.Input[builtins.str] file_system_type: 文件系统类型，默认为 VePFS。
        :param pulumi.Input[builtins.str] free_time: 文件系统释放时间。
        :param pulumi.Input[builtins.str] project_name: 文件系统所属项目，默认为 default。
        :param pulumi.Input[builtins.str] protocol_type: 协议类型，默认为 VePFS。
        :param pulumi.Input[builtins.int] read_bandwidth: 读带宽值, 单位MB/s。
        :param pulumi.Input[builtins.str] security_group_id: 生成的辅助网卡所在的安全组ID。
        :param pulumi.Input[builtins.str] status: 文件系统状态。取值说明如下：Running：实例运行中。Creating：实例创建中。CreateError：实例创建失败。Updating：实例更新中。UpdateError：实例更新失败。Expanding：实例扩容中。ExpandError：实例扩容失败。Deleting：实例删除中。DeleteError：实例删除失败。Stopped：实例已关停。Error：实例处于错误状态。
        :param pulumi.Input[builtins.str] stop_service_time: 文件系统关停时间。
        :param pulumi.Input[builtins.str] store_type: 文件系统规格，取值说明如下：Advance*100：100MB/s/TiB。Performance：性能版。Intelligent*Computing：智算版。
        :param pulumi.Input[builtins.str] store_type_cn: 文件系统规格中文名称，支持如下：100MB/s/TiB。性能版。智算版。
        :param pulumi.Input[builtins.str] store_type_en: 存储类型英文名。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。子网必须属于所选的可用区。
        :param pulumi.Input[builtins.str] updated_time: 文件系统更新时间。
        :param pulumi.Input[builtins.str] version_number: 文件系统版本号。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        :param pulumi.Input[builtins.int] write_bandwidth: 写带宽值, 单位MB/s。
        :param pulumi.Input[builtins.str] zone_id: 可用区 ID。
        :param pulumi.Input[builtins.str] zone_name: 可用区名称。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if capacity_info is not None:
            pulumi.set(__self__, "capacity_info", capacity_info)
        if charge_status is not None:
            pulumi.set(__self__, "charge_status", charge_status)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_restripe is not None:
            pulumi.set(__self__, "enable_restripe", enable_restripe)
        if expire_time is not None:
            pulumi.set(__self__, "expire_time", expire_time)
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if file_system_name is not None:
            pulumi.set(__self__, "file_system_name", file_system_name)
        if file_system_type is not None:
            pulumi.set(__self__, "file_system_type", file_system_type)
        if free_time is not None:
            pulumi.set(__self__, "free_time", free_time)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if protocol_type is not None:
            pulumi.set(__self__, "protocol_type", protocol_type)
        if read_bandwidth is not None:
            pulumi.set(__self__, "read_bandwidth", read_bandwidth)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if stop_service_time is not None:
            pulumi.set(__self__, "stop_service_time", stop_service_time)
        if store_type is not None:
            pulumi.set(__self__, "store_type", store_type)
        if store_type_cn is not None:
            pulumi.set(__self__, "store_type_cn", store_type_cn)
        if store_type_en is not None:
            pulumi.set(__self__, "store_type_en", store_type_en)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if version_number is not None:
            pulumi.set(__self__, "version_number", version_number)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if write_bandwidth is not None:
            pulumi.set(__self__, "write_bandwidth", write_bandwidth)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)
        if zone_name is not None:
            pulumi.set(__self__, "zone_name", zone_name)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账户ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        vePFS 文件系统吞吐上限。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        文件系统容量，单位为 TiB。
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter(name="capacityInfo")
    def capacity_info(self) -> Optional[pulumi.Input['InstanceCapacityInfoArgs']]:
        """
        容量信息。
        """
        return pulumi.get(self, "capacity_info")

    @capacity_info.setter
    def capacity_info(self, value: Optional[pulumi.Input['InstanceCapacityInfoArgs']]):
        pulumi.set(self, "capacity_info", value)

    @property
    @pulumi.getter(name="chargeStatus")
    def charge_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        计费状态，默认为 Normal，表示正常计费。
        """
        return pulumi.get(self, "charge_status")

    @charge_status.setter
    def charge_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_status", value)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        计费类型。取值说明如下：PayAsYouGo：按量计费。
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableRestripe")
    def enable_restripe(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        扩容后是否开启数据均衡，取值说明如下：true：扩容后立即开启数据均衡。false：扩容后不开启数据均衡。注意：仅 100MB/s/TiB 规格的文件系统支持数据均衡功能。由于数据均衡过程会消耗存储节点的网络和磁盘带宽，导致文件系统的性能下降，建议您评估业务需求，谨慎开启。数据均衡的时间主要受存量数据量的影响，如果您的存量数据较多，均衡的时间可能会较长，根据扩容容量大小和文件系统状态，此过程可能需要花费数小时至 2 天的时间，建议您在业务低峰期开启并耐心等待。
        """
        return pulumi.get(self, "enable_restripe")

    @enable_restripe.setter
    def enable_restripe(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_restripe", value)

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        过期时间。
        """
        return pulumi.get(self, "expire_time")

    @expire_time.setter
    def expire_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expire_time", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统名称。命名规范如下：只能以中文或英文开头。只能包含中文、字母、数字、半角句号（.）、下划线（_）或中划线（-）。长度需要在 1~128 个字符内。
        """
        return pulumi.get(self, "file_system_name")

    @file_system_name.setter
    def file_system_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_name", value)

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统类型，默认为 VePFS。
        """
        return pulumi.get(self, "file_system_type")

    @file_system_type.setter
    def file_system_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_type", value)

    @property
    @pulumi.getter(name="freeTime")
    def free_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统释放时间。
        """
        return pulumi.get(self, "free_time")

    @free_time.setter
    def free_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "free_time", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统所属项目，默认为 default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        协议类型，默认为 VePFS。
        """
        return pulumi.get(self, "protocol_type")

    @protocol_type.setter
    def protocol_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol_type", value)

    @property
    @pulumi.getter(name="readBandwidth")
    def read_bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        读带宽值, 单位MB/s。
        """
        return pulumi.get(self, "read_bandwidth")

    @read_bandwidth.setter
    def read_bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "read_bandwidth", value)

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        生成的辅助网卡所在的安全组ID。
        """
        return pulumi.get(self, "security_group_id")

    @security_group_id.setter
    def security_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统状态。取值说明如下：Running：实例运行中。Creating：实例创建中。CreateError：实例创建失败。Updating：实例更新中。UpdateError：实例更新失败。Expanding：实例扩容中。ExpandError：实例扩容失败。Deleting：实例删除中。DeleteError：实例删除失败。Stopped：实例已关停。Error：实例处于错误状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="stopServiceTime")
    def stop_service_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统关停时间。
        """
        return pulumi.get(self, "stop_service_time")

    @stop_service_time.setter
    def stop_service_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stop_service_time", value)

    @property
    @pulumi.getter(name="storeType")
    def store_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统规格，取值说明如下：Advance*100：100MB/s/TiB。Performance：性能版。Intelligent*Computing：智算版。
        """
        return pulumi.get(self, "store_type")

    @store_type.setter
    def store_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "store_type", value)

    @property
    @pulumi.getter(name="storeTypeCn")
    def store_type_cn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统规格中文名称，支持如下：100MB/s/TiB。性能版。智算版。
        """
        return pulumi.get(self, "store_type_cn")

    @store_type_cn.setter
    def store_type_cn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "store_type_cn", value)

    @property
    @pulumi.getter(name="storeTypeEn")
    def store_type_en(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        存储类型英文名。
        """
        return pulumi.get(self, "store_type_en")

    @store_type_en.setter
    def store_type_en(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "store_type_en", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网 ID。子网必须属于所选的可用区。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统版本号。
        """
        return pulumi.get(self, "version_number")

    @version_number.setter
    def version_number(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_number", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="writeBandwidth")
    def write_bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        写带宽值, 单位MB/s。
        """
        return pulumi.get(self, "write_bandwidth")

    @write_bandwidth.setter
    def write_bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "write_bandwidth", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        可用区名称。
        """
        return pulumi.get(self, "zone_name")

    @zone_name.setter
    def zone_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_name", value)


@pulumi.type_token("bytepluscc:vepfs/instance:Instance")
class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[builtins.int]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_restripe: Optional[pulumi.Input[builtins.bool]] = None,
                 file_system_name: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 store_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 version_number: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        文件存储 vePFS 是推出的一种高吞吐、低延时、可扩展并行的文件系统服务，满足高性能计算场景下高吞吐低延时的数据读写需求，可广泛应用于 HPC 高性能计算、AI 人工智能训练或推理、能源勘探、工业仿真、影视渲染、生命科学、气象分析等场景。同时，vePFS 提供一键化部署及配套监控报警能力，免去部署、维护费用的同时，最大化提升您的业务效率。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_epfs_instance_demo = bytepluscc.vepfs.Instance("VEPFSInstanceDemo",
            file_system_name="VEPFSInstanceDemo",
            zone_id="cn-beijing-a",
            charge_type="PayAsYouGo",
            file_system_type="VePFS",
            store_type="Advance_100",
            protocol_type="VePFS",
            project_name="default",
            capacity=8,
            vpc_id="vpc-3nqt4kq87xn28931eclxxxxx",
            subnet_id="subnet-1a0zgr5e7hslc8nvepkxxxxxx",
            version_number="1.4.0",
            enable_restripe=True,
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vepfs/instance:Instance example "file_system_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] capacity: 文件系统容量，单位为 TiB。
        :param pulumi.Input[builtins.str] charge_type: 计费类型。取值说明如下：PayAsYouGo：按量计费。
        :param pulumi.Input[builtins.str] description: 文件系统描述信息。
        :param pulumi.Input[builtins.bool] enable_restripe: 扩容后是否开启数据均衡，取值说明如下：true：扩容后立即开启数据均衡。false：扩容后不开启数据均衡。注意：仅 100MB/s/TiB 规格的文件系统支持数据均衡功能。由于数据均衡过程会消耗存储节点的网络和磁盘带宽，导致文件系统的性能下降，建议您评估业务需求，谨慎开启。数据均衡的时间主要受存量数据量的影响，如果您的存量数据较多，均衡的时间可能会较长，根据扩容容量大小和文件系统状态，此过程可能需要花费数小时至 2 天的时间，建议您在业务低峰期开启并耐心等待。
        :param pulumi.Input[builtins.str] file_system_name: 文件系统名称。命名规范如下：只能以中文或英文开头。只能包含中文、字母、数字、半角句号（.）、下划线（_）或中划线（-）。长度需要在 1~128 个字符内。
        :param pulumi.Input[builtins.str] file_system_type: 文件系统类型，默认为 VePFS。
        :param pulumi.Input[builtins.str] project_name: 文件系统所属项目，默认为 default。
        :param pulumi.Input[builtins.str] protocol_type: 协议类型，默认为 VePFS。
        :param pulumi.Input[builtins.str] store_type: 文件系统规格，取值说明如下：Advance*100：100MB/s/TiB。Performance：性能版。Intelligent*Computing：智算版。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。子网必须属于所选的可用区。
        :param pulumi.Input[builtins.str] version_number: 文件系统版本号。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        :param pulumi.Input[builtins.str] zone_id: 可用区 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        文件存储 vePFS 是推出的一种高吞吐、低延时、可扩展并行的文件系统服务，满足高性能计算场景下高吞吐低延时的数据读写需求，可广泛应用于 HPC 高性能计算、AI 人工智能训练或推理、能源勘探、工业仿真、影视渲染、生命科学、气象分析等场景。同时，vePFS 提供一键化部署及配套监控报警能力，免去部署、维护费用的同时，最大化提升您的业务效率。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_epfs_instance_demo = bytepluscc.vepfs.Instance("VEPFSInstanceDemo",
            file_system_name="VEPFSInstanceDemo",
            zone_id="cn-beijing-a",
            charge_type="PayAsYouGo",
            file_system_type="VePFS",
            store_type="Advance_100",
            protocol_type="VePFS",
            project_name="default",
            capacity=8,
            vpc_id="vpc-3nqt4kq87xn28931eclxxxxx",
            subnet_id="subnet-1a0zgr5e7hslc8nvepkxxxxxx",
            version_number="1.4.0",
            enable_restripe=True,
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vepfs/instance:Instance example "file_system_id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[builtins.int]] = None,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_restripe: Optional[pulumi.Input[builtins.bool]] = None,
                 file_system_name: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 store_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 version_number: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            if capacity is None and not opts.urn:
                raise TypeError("Missing required property 'capacity'")
            __props__.__dict__["capacity"] = capacity
            __props__.__dict__["charge_type"] = charge_type
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_restripe"] = enable_restripe
            if file_system_name is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_name'")
            __props__.__dict__["file_system_name"] = file_system_name
            __props__.__dict__["file_system_type"] = file_system_type
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["protocol_type"] = protocol_type
            if store_type is None and not opts.urn:
                raise TypeError("Missing required property 'store_type'")
            __props__.__dict__["store_type"] = store_type
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["version_number"] = version_number
            __props__.__dict__["vpc_id"] = vpc_id
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["account_id"] = None
            __props__.__dict__["bandwidth"] = None
            __props__.__dict__["capacity_info"] = None
            __props__.__dict__["charge_status"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["expire_time"] = None
            __props__.__dict__["file_system_id"] = None
            __props__.__dict__["free_time"] = None
            __props__.__dict__["read_bandwidth"] = None
            __props__.__dict__["security_group_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["stop_service_time"] = None
            __props__.__dict__["store_type_cn"] = None
            __props__.__dict__["store_type_en"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["write_bandwidth"] = None
            __props__.__dict__["zone_name"] = None
        super(Instance, __self__).__init__(
            'bytepluscc:vepfs/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            capacity: Optional[pulumi.Input[builtins.int]] = None,
            capacity_info: Optional[pulumi.Input[Union['InstanceCapacityInfoArgs', 'InstanceCapacityInfoArgsDict']]] = None,
            charge_status: Optional[pulumi.Input[builtins.str]] = None,
            charge_type: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enable_restripe: Optional[pulumi.Input[builtins.bool]] = None,
            expire_time: Optional[pulumi.Input[builtins.str]] = None,
            file_system_id: Optional[pulumi.Input[builtins.str]] = None,
            file_system_name: Optional[pulumi.Input[builtins.str]] = None,
            file_system_type: Optional[pulumi.Input[builtins.str]] = None,
            free_time: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            protocol_type: Optional[pulumi.Input[builtins.str]] = None,
            read_bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            security_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            stop_service_time: Optional[pulumi.Input[builtins.str]] = None,
            store_type: Optional[pulumi.Input[builtins.str]] = None,
            store_type_cn: Optional[pulumi.Input[builtins.str]] = None,
            store_type_en: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            version_number: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            write_bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 账户ID。
        :param pulumi.Input[builtins.int] bandwidth: vePFS 文件系统吞吐上限。
        :param pulumi.Input[builtins.int] capacity: 文件系统容量，单位为 TiB。
        :param pulumi.Input[Union['InstanceCapacityInfoArgs', 'InstanceCapacityInfoArgsDict']] capacity_info: 容量信息。
        :param pulumi.Input[builtins.str] charge_status: 计费状态，默认为 Normal，表示正常计费。
        :param pulumi.Input[builtins.str] charge_type: 计费类型。取值说明如下：PayAsYouGo：按量计费。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 文件系统描述信息。
        :param pulumi.Input[builtins.bool] enable_restripe: 扩容后是否开启数据均衡，取值说明如下：true：扩容后立即开启数据均衡。false：扩容后不开启数据均衡。注意：仅 100MB/s/TiB 规格的文件系统支持数据均衡功能。由于数据均衡过程会消耗存储节点的网络和磁盘带宽，导致文件系统的性能下降，建议您评估业务需求，谨慎开启。数据均衡的时间主要受存量数据量的影响，如果您的存量数据较多，均衡的时间可能会较长，根据扩容容量大小和文件系统状态，此过程可能需要花费数小时至 2 天的时间，建议您在业务低峰期开启并耐心等待。
        :param pulumi.Input[builtins.str] expire_time: 过期时间。
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] file_system_name: 文件系统名称。命名规范如下：只能以中文或英文开头。只能包含中文、字母、数字、半角句号（.）、下划线（_）或中划线（-）。长度需要在 1~128 个字符内。
        :param pulumi.Input[builtins.str] file_system_type: 文件系统类型，默认为 VePFS。
        :param pulumi.Input[builtins.str] free_time: 文件系统释放时间。
        :param pulumi.Input[builtins.str] project_name: 文件系统所属项目，默认为 default。
        :param pulumi.Input[builtins.str] protocol_type: 协议类型，默认为 VePFS。
        :param pulumi.Input[builtins.int] read_bandwidth: 读带宽值, 单位MB/s。
        :param pulumi.Input[builtins.str] security_group_id: 生成的辅助网卡所在的安全组ID。
        :param pulumi.Input[builtins.str] status: 文件系统状态。取值说明如下：Running：实例运行中。Creating：实例创建中。CreateError：实例创建失败。Updating：实例更新中。UpdateError：实例更新失败。Expanding：实例扩容中。ExpandError：实例扩容失败。Deleting：实例删除中。DeleteError：实例删除失败。Stopped：实例已关停。Error：实例处于错误状态。
        :param pulumi.Input[builtins.str] stop_service_time: 文件系统关停时间。
        :param pulumi.Input[builtins.str] store_type: 文件系统规格，取值说明如下：Advance*100：100MB/s/TiB。Performance：性能版。Intelligent*Computing：智算版。
        :param pulumi.Input[builtins.str] store_type_cn: 文件系统规格中文名称，支持如下：100MB/s/TiB。性能版。智算版。
        :param pulumi.Input[builtins.str] store_type_en: 存储类型英文名。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。子网必须属于所选的可用区。
        :param pulumi.Input[builtins.str] updated_time: 文件系统更新时间。
        :param pulumi.Input[builtins.str] version_number: 文件系统版本号。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        :param pulumi.Input[builtins.int] write_bandwidth: 写带宽值, 单位MB/s。
        :param pulumi.Input[builtins.str] zone_id: 可用区 ID。
        :param pulumi.Input[builtins.str] zone_name: 可用区名称。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["capacity"] = capacity
        __props__.__dict__["capacity_info"] = capacity_info
        __props__.__dict__["charge_status"] = charge_status
        __props__.__dict__["charge_type"] = charge_type
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_restripe"] = enable_restripe
        __props__.__dict__["expire_time"] = expire_time
        __props__.__dict__["file_system_id"] = file_system_id
        __props__.__dict__["file_system_name"] = file_system_name
        __props__.__dict__["file_system_type"] = file_system_type
        __props__.__dict__["free_time"] = free_time
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["protocol_type"] = protocol_type
        __props__.__dict__["read_bandwidth"] = read_bandwidth
        __props__.__dict__["security_group_id"] = security_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["stop_service_time"] = stop_service_time
        __props__.__dict__["store_type"] = store_type
        __props__.__dict__["store_type_cn"] = store_type_cn
        __props__.__dict__["store_type_en"] = store_type_en
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["version_number"] = version_number
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["write_bandwidth"] = write_bandwidth
        __props__.__dict__["zone_id"] = zone_id
        __props__.__dict__["zone_name"] = zone_name
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        账户ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        vePFS 文件系统吞吐上限。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter
    def capacity(self) -> pulumi.Output[builtins.int]:
        """
        文件系统容量，单位为 TiB。
        """
        return pulumi.get(self, "capacity")

    @property
    @pulumi.getter(name="capacityInfo")
    def capacity_info(self) -> pulumi.Output['outputs.InstanceCapacityInfo']:
        """
        容量信息。
        """
        return pulumi.get(self, "capacity_info")

    @property
    @pulumi.getter(name="chargeStatus")
    def charge_status(self) -> pulumi.Output[builtins.str]:
        """
        计费状态，默认为 Normal，表示正常计费。
        """
        return pulumi.get(self, "charge_status")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> pulumi.Output[builtins.str]:
        """
        计费类型。取值说明如下：PayAsYouGo：按量计费。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        文件系统描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableRestripe")
    def enable_restripe(self) -> pulumi.Output[builtins.bool]:
        """
        扩容后是否开启数据均衡，取值说明如下：true：扩容后立即开启数据均衡。false：扩容后不开启数据均衡。注意：仅 100MB/s/TiB 规格的文件系统支持数据均衡功能。由于数据均衡过程会消耗存储节点的网络和磁盘带宽，导致文件系统的性能下降，建议您评估业务需求，谨慎开启。数据均衡的时间主要受存量数据量的影响，如果您的存量数据较多，均衡的时间可能会较长，根据扩容容量大小和文件系统状态，此过程可能需要花费数小时至 2 天的时间，建议您在业务低峰期开启并耐心等待。
        """
        return pulumi.get(self, "enable_restripe")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> pulumi.Output[builtins.str]:
        """
        过期时间。
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Output[builtins.str]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> pulumi.Output[builtins.str]:
        """
        文件系统名称。命名规范如下：只能以中文或英文开头。只能包含中文、字母、数字、半角句号（.）、下划线（_）或中划线（-）。长度需要在 1~128 个字符内。
        """
        return pulumi.get(self, "file_system_name")

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> pulumi.Output[builtins.str]:
        """
        文件系统类型，默认为 VePFS。
        """
        return pulumi.get(self, "file_system_type")

    @property
    @pulumi.getter(name="freeTime")
    def free_time(self) -> pulumi.Output[builtins.str]:
        """
        文件系统释放时间。
        """
        return pulumi.get(self, "free_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        文件系统所属项目，默认为 default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> pulumi.Output[builtins.str]:
        """
        协议类型，默认为 VePFS。
        """
        return pulumi.get(self, "protocol_type")

    @property
    @pulumi.getter(name="readBandwidth")
    def read_bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        读带宽值, 单位MB/s。
        """
        return pulumi.get(self, "read_bandwidth")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> pulumi.Output[builtins.str]:
        """
        生成的辅助网卡所在的安全组ID。
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        文件系统状态。取值说明如下：Running：实例运行中。Creating：实例创建中。CreateError：实例创建失败。Updating：实例更新中。UpdateError：实例更新失败。Expanding：实例扩容中。ExpandError：实例扩容失败。Deleting：实例删除中。DeleteError：实例删除失败。Stopped：实例已关停。Error：实例处于错误状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="stopServiceTime")
    def stop_service_time(self) -> pulumi.Output[builtins.str]:
        """
        文件系统关停时间。
        """
        return pulumi.get(self, "stop_service_time")

    @property
    @pulumi.getter(name="storeType")
    def store_type(self) -> pulumi.Output[builtins.str]:
        """
        文件系统规格，取值说明如下：Advance*100：100MB/s/TiB。Performance：性能版。Intelligent*Computing：智算版。
        """
        return pulumi.get(self, "store_type")

    @property
    @pulumi.getter(name="storeTypeCn")
    def store_type_cn(self) -> pulumi.Output[builtins.str]:
        """
        文件系统规格中文名称，支持如下：100MB/s/TiB。性能版。智算版。
        """
        return pulumi.get(self, "store_type_cn")

    @property
    @pulumi.getter(name="storeTypeEn")
    def store_type_en(self) -> pulumi.Output[builtins.str]:
        """
        存储类型英文名。
        """
        return pulumi.get(self, "store_type_en")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        子网 ID。子网必须属于所选的可用区。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.InstanceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        文件系统更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> pulumi.Output[builtins.str]:
        """
        文件系统版本号。
        """
        return pulumi.get(self, "version_number")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="writeBandwidth")
    def write_bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        写带宽值, 单位MB/s。
        """
        return pulumi.get(self, "write_bandwidth")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> pulumi.Output[builtins.str]:
        """
        可用区名称。
        """
        return pulumi.get(self, "zone_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetShareConfigResult',
    'AwaitableGetShareConfigResult',
    'get_share_config',
    'get_share_config_output',
]

@pulumi.output_type
class GetShareConfigResult:
    """
    A collection of values returned by getShareConfig.
    """
    def __init__(__self__, allow_ip_access_rule=None, allow_referer_access_rule=None, common_matchs=None, config_name=None, config_type=None, deny_ip_access_rule=None, deny_referer_access_rule=None, domain_count=None, id=None, project=None, rule_content=None, updated_time=None):
        if allow_ip_access_rule and not isinstance(allow_ip_access_rule, dict):
            raise TypeError("Expected argument 'allow_ip_access_rule' to be a dict")
        pulumi.set(__self__, "allow_ip_access_rule", allow_ip_access_rule)
        if allow_referer_access_rule and not isinstance(allow_referer_access_rule, dict):
            raise TypeError("Expected argument 'allow_referer_access_rule' to be a dict")
        pulumi.set(__self__, "allow_referer_access_rule", allow_referer_access_rule)
        if common_matchs and not isinstance(common_matchs, dict):
            raise TypeError("Expected argument 'common_matchs' to be a dict")
        pulumi.set(__self__, "common_matchs", common_matchs)
        if config_name and not isinstance(config_name, str):
            raise TypeError("Expected argument 'config_name' to be a str")
        pulumi.set(__self__, "config_name", config_name)
        if config_type and not isinstance(config_type, str):
            raise TypeError("Expected argument 'config_type' to be a str")
        pulumi.set(__self__, "config_type", config_type)
        if deny_ip_access_rule and not isinstance(deny_ip_access_rule, dict):
            raise TypeError("Expected argument 'deny_ip_access_rule' to be a dict")
        pulumi.set(__self__, "deny_ip_access_rule", deny_ip_access_rule)
        if deny_referer_access_rule and not isinstance(deny_referer_access_rule, dict):
            raise TypeError("Expected argument 'deny_referer_access_rule' to be a dict")
        pulumi.set(__self__, "deny_referer_access_rule", deny_referer_access_rule)
        if domain_count and not isinstance(domain_count, int):
            raise TypeError("Expected argument 'domain_count' to be a int")
        pulumi.set(__self__, "domain_count", domain_count)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if rule_content and not isinstance(rule_content, str):
            raise TypeError("Expected argument 'rule_content' to be a str")
        pulumi.set(__self__, "rule_content", rule_content)
        if updated_time and not isinstance(updated_time, int):
            raise TypeError("Expected argument 'updated_time' to be a int")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="allowIpAccessRule")
    def allow_ip_access_rule(self) -> 'outputs.GetShareConfigAllowIpAccessRuleResult':
        """
        表示一个 IP 白名单的配置，对应 ConfigType 是 allow*ip*access*rule。
        """
        return pulumi.get(self, "allow_ip_access_rule")

    @property
    @pulumi.getter(name="allowRefererAccessRule")
    def allow_referer_access_rule(self) -> 'outputs.GetShareConfigAllowRefererAccessRuleResult':
        """
        表示一个 Referer 白名单的配置，对应 ConfigType 是 allow*referer*access*rule。
        """
        return pulumi.get(self, "allow_referer_access_rule")

    @property
    @pulumi.getter(name="commonMatchs")
    def common_matchs(self) -> 'outputs.GetShareConfigCommonMatchsResult':
        """
        表示一个通用列表的配置，对应 ConfigType 是 common*match*list。
        """
        return pulumi.get(self, "common_matchs")

    @property
    @pulumi.getter(name="configName")
    def config_name(self) -> builtins.str:
        """
        表示全局配置的名称。名称有以下要求：名称可以包含汉字、字母、数字、下划线（_），长度在 3-45 个字符之间。一个汉字占 3 个字符。名称不能与主账号下某个已有的全局配置的名称相同。
        """
        return pulumi.get(self, "config_name")

    @property
    @pulumi.getter(name="configType")
    def config_type(self) -> builtins.str:
        """
        表示该全局配置的类型。该参数有以下取值：deny*ip*access*rule：表示 IP 黑名单。allow*ip*access*rule：表示 IP 白名单。deny*referer*access*rule：表示 Referer 黑名单。allow*referer*access*rule：表示 Referer 白名单。common*match*list：表示通用列表。
        """
        return pulumi.get(self, "config_type")

    @property
    @pulumi.getter(name="denyIpAccessRule")
    def deny_ip_access_rule(self) -> 'outputs.GetShareConfigDenyIpAccessRuleResult':
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access*rule。
        """
        return pulumi.get(self, "deny_ip_access_rule")

    @property
    @pulumi.getter(name="denyRefererAccessRule")
    def deny_referer_access_rule(self) -> 'outputs.GetShareConfigDenyRefererAccessRuleResult':
        """
        表示一个 Referer 黑名单的配置，对应 ConfigType 是 deny*referer*access*rule。
        """
        return pulumi.get(self, "deny_referer_access_rule")

    @property
    @pulumi.getter(name="domainCount")
    def domain_count(self) -> builtins.int:
        """
        表示与该全局配置关联的加速域名的数量。
        """
        return pulumi.get(self, "domain_count")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def project(self) -> builtins.str:
        """
        表示该全局配置所归属的项目名称。
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="ruleContent")
    def rule_content(self) -> builtins.str:
        """
        表示该自定义错误页面的 HTML 代码。
        """
        return pulumi.get(self, "rule_content")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.int:
        """
        表示该全局配置的最近修改时间，单位是 Unix 时间戳。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetShareConfigResult(GetShareConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetShareConfigResult(
            allow_ip_access_rule=self.allow_ip_access_rule,
            allow_referer_access_rule=self.allow_referer_access_rule,
            common_matchs=self.common_matchs,
            config_name=self.config_name,
            config_type=self.config_type,
            deny_ip_access_rule=self.deny_ip_access_rule,
            deny_referer_access_rule=self.deny_referer_access_rule,
            domain_count=self.domain_count,
            id=self.id,
            project=self.project,
            rule_content=self.rule_content,
            updated_time=self.updated_time)


def get_share_config(id: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetShareConfigResult:
    """
    Data Source schema for Byteplus::CDN::ShareConfig


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cdn/getShareConfig:getShareConfig', __args__, opts=opts, typ=GetShareConfigResult).value

    return AwaitableGetShareConfigResult(
        allow_ip_access_rule=pulumi.get(__ret__, 'allow_ip_access_rule'),
        allow_referer_access_rule=pulumi.get(__ret__, 'allow_referer_access_rule'),
        common_matchs=pulumi.get(__ret__, 'common_matchs'),
        config_name=pulumi.get(__ret__, 'config_name'),
        config_type=pulumi.get(__ret__, 'config_type'),
        deny_ip_access_rule=pulumi.get(__ret__, 'deny_ip_access_rule'),
        deny_referer_access_rule=pulumi.get(__ret__, 'deny_referer_access_rule'),
        domain_count=pulumi.get(__ret__, 'domain_count'),
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'),
        rule_content=pulumi.get(__ret__, 'rule_content'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_share_config_output(id: Optional[pulumi.Input[builtins.str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetShareConfigResult]:
    """
    Data Source schema for Byteplus::CDN::ShareConfig


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cdn/getShareConfig:getShareConfig', __args__, opts=opts, typ=GetShareConfigResult)
    return __ret__.apply(lambda __response__: GetShareConfigResult(
        allow_ip_access_rule=pulumi.get(__response__, 'allow_ip_access_rule'),
        allow_referer_access_rule=pulumi.get(__response__, 'allow_referer_access_rule'),
        common_matchs=pulumi.get(__response__, 'common_matchs'),
        config_name=pulumi.get(__response__, 'config_name'),
        config_type=pulumi.get(__response__, 'config_type'),
        deny_ip_access_rule=pulumi.get(__response__, 'deny_ip_access_rule'),
        deny_referer_access_rule=pulumi.get(__response__, 'deny_referer_access_rule'),
        domain_count=pulumi.get(__response__, 'domain_count'),
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project'),
        rule_content=pulumi.get(__response__, 'rule_content'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UpstreamSourceArgs', 'UpstreamSource']

@pulumi.input_type
class UpstreamSourceArgs:
    def __init__(__self__, *,
                 gateway_id: pulumi.Input[builtins.str],
                 source_spec: pulumi.Input['UpstreamSourceSourceSpecArgs'],
                 source_type: pulumi.Input[builtins.str],
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 ingress_settings: Optional[pulumi.Input['UpstreamSourceIngressSettingsArgs']] = None,
                 watch_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a UpstreamSource resource.
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input['UpstreamSourceSourceSpecArgs'] source_spec: Upstream来源配置。
        :param pulumi.Input[builtins.str] source_type: Upstream来源类型，取值：K8S：容器集群。Nacos：注册中心。
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input['UpstreamSourceIngressSettingsArgs'] ingress_settings: 路由同步。开启后，API网关会自动监听Ingress资源的变化，并将Ingress资源转义为服务，域名，Upstream等资源合并至当前网关。由Ingress转义的资源不支持在控制台操作。仅支持容器集群来源类型。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] watch_namespaces: 指定命名空间。
        """
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "source_spec", source_spec)
        pulumi.set(__self__, "source_type", source_type)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if ingress_settings is not None:
            pulumi.set(__self__, "ingress_settings", ingress_settings)
        if watch_namespaces is not None:
            pulumi.set(__self__, "watch_namespaces", watch_namespaces)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter(name="sourceSpec")
    def source_spec(self) -> pulumi.Input['UpstreamSourceSourceSpecArgs']:
        """
        Upstream来源配置。
        """
        return pulumi.get(self, "source_spec")

    @source_spec.setter
    def source_spec(self, value: pulumi.Input['UpstreamSourceSourceSpecArgs']):
        pulumi.set(self, "source_spec", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Input[builtins.str]:
        """
        Upstream来源类型，取值：K8S：容器集群。Nacos：注册中心。
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="ingressSettings")
    def ingress_settings(self) -> Optional[pulumi.Input['UpstreamSourceIngressSettingsArgs']]:
        """
        路由同步。开启后，API网关会自动监听Ingress资源的变化，并将Ingress资源转义为服务，域名，Upstream等资源合并至当前网关。由Ingress转义的资源不支持在控制台操作。仅支持容器集群来源类型。
        """
        return pulumi.get(self, "ingress_settings")

    @ingress_settings.setter
    def ingress_settings(self, value: Optional[pulumi.Input['UpstreamSourceIngressSettingsArgs']]):
        pulumi.set(self, "ingress_settings", value)

    @property
    @pulumi.getter(name="watchNamespaces")
    def watch_namespaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        指定命名空间。
        """
        return pulumi.get(self, "watch_namespaces")

    @watch_namespaces.setter
    def watch_namespaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "watch_namespaces", value)


@pulumi.input_type
class _UpstreamSourceState:
    def __init__(__self__, *,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ingress_settings: Optional[pulumi.Input['UpstreamSourceIngressSettingsArgs']] = None,
                 source_spec: Optional[pulumi.Input['UpstreamSourceSourceSpecArgs']] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 status_message: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 upstream_source_id: Optional[pulumi.Input[builtins.str]] = None,
                 watch_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering UpstreamSource resources.
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input['UpstreamSourceIngressSettingsArgs'] ingress_settings: 路由同步。开启后，API网关会自动监听Ingress资源的变化，并将Ingress资源转义为服务，域名，Upstream等资源合并至当前网关。由Ingress转义的资源不支持在控制台操作。仅支持容器集群来源类型。
        :param pulumi.Input['UpstreamSourceSourceSpecArgs'] source_spec: Upstream来源配置。
        :param pulumi.Input[builtins.str] source_type: Upstream来源类型，取值：K8S：容器集群。Nacos：注册中心。
        :param pulumi.Input[builtins.str] status: 导入状态，取值：Syncing：导入中。SyncedSucceed：导入成功。SyncedFailed：导入失败。
        :param pulumi.Input[builtins.str] status_message: 导入状态信息，取值：ConnectionFailed：Nacos集群无法连接。AuthenticationFailed：认证失败。PermissionFailed：Nacos集群无法连接。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] upstream_source_id: Upstream来源ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] watch_namespaces: 指定命名空间。
        """
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if gateway_id is not None:
            pulumi.set(__self__, "gateway_id", gateway_id)
        if ingress_settings is not None:
            pulumi.set(__self__, "ingress_settings", ingress_settings)
        if source_spec is not None:
            pulumi.set(__self__, "source_spec", source_spec)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if status_message is not None:
            pulumi.set(__self__, "status_message", status_message)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if upstream_source_id is not None:
            pulumi.set(__self__, "upstream_source_id", upstream_source_id)
        if watch_namespaces is not None:
            pulumi.set(__self__, "watch_namespaces", watch_namespaces)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter(name="ingressSettings")
    def ingress_settings(self) -> Optional[pulumi.Input['UpstreamSourceIngressSettingsArgs']]:
        """
        路由同步。开启后，API网关会自动监听Ingress资源的变化，并将Ingress资源转义为服务，域名，Upstream等资源合并至当前网关。由Ingress转义的资源不支持在控制台操作。仅支持容器集群来源类型。
        """
        return pulumi.get(self, "ingress_settings")

    @ingress_settings.setter
    def ingress_settings(self, value: Optional[pulumi.Input['UpstreamSourceIngressSettingsArgs']]):
        pulumi.set(self, "ingress_settings", value)

    @property
    @pulumi.getter(name="sourceSpec")
    def source_spec(self) -> Optional[pulumi.Input['UpstreamSourceSourceSpecArgs']]:
        """
        Upstream来源配置。
        """
        return pulumi.get(self, "source_spec")

    @source_spec.setter
    def source_spec(self, value: Optional[pulumi.Input['UpstreamSourceSourceSpecArgs']]):
        pulumi.set(self, "source_spec", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Upstream来源类型，取值：K8S：容器集群。Nacos：注册中心。
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        导入状态，取值：Syncing：导入中。SyncedSucceed：导入成功。SyncedFailed：导入失败。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        导入状态信息，取值：ConnectionFailed：Nacos集群无法连接。AuthenticationFailed：认证失败。PermissionFailed：Nacos集群无法连接。
        """
        return pulumi.get(self, "status_message")

    @status_message.setter
    def status_message(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status_message", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="upstreamSourceId")
    def upstream_source_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Upstream来源ID。
        """
        return pulumi.get(self, "upstream_source_id")

    @upstream_source_id.setter
    def upstream_source_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "upstream_source_id", value)

    @property
    @pulumi.getter(name="watchNamespaces")
    def watch_namespaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        指定命名空间。
        """
        return pulumi.get(self, "watch_namespaces")

    @watch_namespaces.setter
    def watch_namespaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "watch_namespaces", value)


@pulumi.type_token("bytepluscc:apig/upstreamSource:UpstreamSource")
class UpstreamSource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ingress_settings: Optional[pulumi.Input[Union['UpstreamSourceIngressSettingsArgs', 'UpstreamSourceIngressSettingsArgsDict']]] = None,
                 source_spec: Optional[pulumi.Input[Union['UpstreamSourceSourceSpecArgs', 'UpstreamSourceSourceSpecArgsDict']]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 watch_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        API 网关支持基于容器服务（VKE）集和容器服务的注册集群功能，将集群导入到 API 网关实例，将其作为网关的 Upstream 来源，以便网关获取集群中的 Service 列表。

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/upstreamSource:UpstreamSource example "upstream_source_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input[Union['UpstreamSourceIngressSettingsArgs', 'UpstreamSourceIngressSettingsArgsDict']] ingress_settings: 路由同步。开启后，API网关会自动监听Ingress资源的变化，并将Ingress资源转义为服务，域名，Upstream等资源合并至当前网关。由Ingress转义的资源不支持在控制台操作。仅支持容器集群来源类型。
        :param pulumi.Input[Union['UpstreamSourceSourceSpecArgs', 'UpstreamSourceSourceSpecArgsDict']] source_spec: Upstream来源配置。
        :param pulumi.Input[builtins.str] source_type: Upstream来源类型，取值：K8S：容器集群。Nacos：注册中心。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] watch_namespaces: 指定命名空间。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UpstreamSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        API 网关支持基于容器服务（VKE）集和容器服务的注册集群功能，将集群导入到 API 网关实例，将其作为网关的 Upstream 来源，以便网关获取集群中的 Service 列表。

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/upstreamSource:UpstreamSource example "upstream_source_id"
        ```

        :param str resource_name: The name of the resource.
        :param UpstreamSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UpstreamSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ingress_settings: Optional[pulumi.Input[Union['UpstreamSourceIngressSettingsArgs', 'UpstreamSourceIngressSettingsArgsDict']]] = None,
                 source_spec: Optional[pulumi.Input[Union['UpstreamSourceSourceSpecArgs', 'UpstreamSourceSourceSpecArgsDict']]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 watch_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UpstreamSourceArgs.__new__(UpstreamSourceArgs)

            __props__.__dict__["comments"] = comments
            if gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'gateway_id'")
            __props__.__dict__["gateway_id"] = gateway_id
            __props__.__dict__["ingress_settings"] = ingress_settings
            if source_spec is None and not opts.urn:
                raise TypeError("Missing required property 'source_spec'")
            __props__.__dict__["source_spec"] = source_spec
            if source_type is None and not opts.urn:
                raise TypeError("Missing required property 'source_type'")
            __props__.__dict__["source_type"] = source_type
            __props__.__dict__["watch_namespaces"] = watch_namespaces
            __props__.__dict__["created_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["status_message"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["upstream_source_id"] = None
        super(UpstreamSource, __self__).__init__(
            'bytepluscc:apig/upstreamSource:UpstreamSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comments: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            ingress_settings: Optional[pulumi.Input[Union['UpstreamSourceIngressSettingsArgs', 'UpstreamSourceIngressSettingsArgsDict']]] = None,
            source_spec: Optional[pulumi.Input[Union['UpstreamSourceSourceSpecArgs', 'UpstreamSourceSourceSpecArgsDict']]] = None,
            source_type: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            status_message: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            upstream_source_id: Optional[pulumi.Input[builtins.str]] = None,
            watch_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'UpstreamSource':
        """
        Get an existing UpstreamSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] comments: 备注，长度限制为0~253个字符。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input[Union['UpstreamSourceIngressSettingsArgs', 'UpstreamSourceIngressSettingsArgsDict']] ingress_settings: 路由同步。开启后，API网关会自动监听Ingress资源的变化，并将Ingress资源转义为服务，域名，Upstream等资源合并至当前网关。由Ingress转义的资源不支持在控制台操作。仅支持容器集群来源类型。
        :param pulumi.Input[Union['UpstreamSourceSourceSpecArgs', 'UpstreamSourceSourceSpecArgsDict']] source_spec: Upstream来源配置。
        :param pulumi.Input[builtins.str] source_type: Upstream来源类型，取值：K8S：容器集群。Nacos：注册中心。
        :param pulumi.Input[builtins.str] status: 导入状态，取值：Syncing：导入中。SyncedSucceed：导入成功。SyncedFailed：导入失败。
        :param pulumi.Input[builtins.str] status_message: 导入状态信息，取值：ConnectionFailed：Nacos集群无法连接。AuthenticationFailed：认证失败。PermissionFailed：Nacos集群无法连接。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] upstream_source_id: Upstream来源ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] watch_namespaces: 指定命名空间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UpstreamSourceState.__new__(_UpstreamSourceState)

        __props__.__dict__["comments"] = comments
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["gateway_id"] = gateway_id
        __props__.__dict__["ingress_settings"] = ingress_settings
        __props__.__dict__["source_spec"] = source_spec
        __props__.__dict__["source_type"] = source_type
        __props__.__dict__["status"] = status
        __props__.__dict__["status_message"] = status_message
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["upstream_source_id"] = upstream_source_id
        __props__.__dict__["watch_namespaces"] = watch_namespaces
        return UpstreamSource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def comments(self) -> pulumi.Output[builtins.str]:
        """
        备注，长度限制为0~253个字符。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter(name="ingressSettings")
    def ingress_settings(self) -> pulumi.Output['outputs.UpstreamSourceIngressSettings']:
        """
        路由同步。开启后，API网关会自动监听Ingress资源的变化，并将Ingress资源转义为服务，域名，Upstream等资源合并至当前网关。由Ingress转义的资源不支持在控制台操作。仅支持容器集群来源类型。
        """
        return pulumi.get(self, "ingress_settings")

    @property
    @pulumi.getter(name="sourceSpec")
    def source_spec(self) -> pulumi.Output['outputs.UpstreamSourceSourceSpec']:
        """
        Upstream来源配置。
        """
        return pulumi.get(self, "source_spec")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Output[builtins.str]:
        """
        Upstream来源类型，取值：K8S：容器集群。Nacos：注册中心。
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        导入状态，取值：Syncing：导入中。SyncedSucceed：导入成功。SyncedFailed：导入失败。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> pulumi.Output[builtins.str]:
        """
        导入状态信息，取值：ConnectionFailed：Nacos集群无法连接。AuthenticationFailed：认证失败。PermissionFailed：Nacos集群无法连接。
        """
        return pulumi.get(self, "status_message")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="upstreamSourceId")
    def upstream_source_id(self) -> pulumi.Output[builtins.str]:
        """
        Upstream来源ID。
        """
        return pulumi.get(self, "upstream_source_id")

    @property
    @pulumi.getter(name="watchNamespaces")
    def watch_namespaces(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        指定命名空间。
        """
        return pulumi.get(self, "watch_namespaces")

